package com.nokia.financeapi.service.house;

import com.nokia.financeapi.common.R;
import com.nokia.financeapi.dao.house.HouseDataCheckDao;
import com.nokia.financeapi.pojo.dto.GetBuildingAreaDiffDto;
import com.nokia.financeapi.pojo.dto.GetHouseAbnormalDataDto;
import com.nokia.financeapi.pojo.vo.GetBuildingAreaDiffVo;
import com.nokia.financeapi.pojo.vo.GetHouseAbnormalDataVo;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class HouseDataCheckService {
    private final HouseDataCheckDao houseDataCheckDao;

    public HouseDataCheckService(HouseDataCheckDao houseDataCheckDao) {
        this.houseDataCheckDao = houseDataCheckDao;
    }

    public R<GetBuildingAreaDiffVo> getBuildingAreaDiff(GetBuildingAreaDiffDto dto) {
        GetBuildingAreaDiffVo vo = houseDataCheckDao.getFirstUnitBuildingAreaDiff();
        List<GetBuildingAreaDiffVo> l2 = houseDataCheckDao.getSecondUnitBuildingAreaDiff();
        vo.setChildren(l2);
        List<GetBuildingAreaDiffVo> l3 = houseDataCheckDao.getThirdUnitBuildingAreaDiff();
        for (GetBuildingAreaDiffVo second : l2) {
            List<GetBuildingAreaDiffVo> l33 = new ArrayList<>();
            second.setChildren(l33);
            for (GetBuildingAreaDiffVo third : l3) {
                if (second.getAreaName().equals(third.getAreaName())) {
                    l33.add(third);
                }
            }
        }
        return R.ok(vo);
    }

    public R<GetHouseAbnormalDataVo> getHouseAbnormalData(GetHouseAbnormalDataDto dto) {
        Integer endDate = dto.getEndDate();
        // 账期为空则取最新的账期
        if (dto.getEndDate() == null) {
            endDate = houseDataCheckDao.getAbnormalDataMaxDate();
        }
        if (endDate == null) {
            return R.ok();
        }
        dto.setEndDate(endDate);
        GetHouseAbnormalDataVo vo = houseDataCheckDao.getFirstUnitAbnormalData(dto);
        if (vo == null || vo.getWeiGuanLianJuZhiSum() == null || vo.getXianZhiJianZhuMianJiSum() == null) {
            return R.ok();
        }
        List<GetHouseAbnormalDataVo> l2 = houseDataCheckDao.getSecondUnitAbnormalData(dto);
        vo.setChildren(l2);
        List<GetHouseAbnormalDataVo> l3 = houseDataCheckDao.getThirdUnitAbnormalData(dto);
        for (GetHouseAbnormalDataVo second : l2) {
            List<GetHouseAbnormalDataVo> l33 = new ArrayList<>();
            second.setChildren(l33);
            for (GetHouseAbnormalDataVo third : l3) {
                if (second.getSecondUnit().equals(third.getSecondUnit())) {
                    l33.add(third);
                }
            }
        }
        return R.ok(vo);
    }
}
